==> lmtpd-0.9.19.tar.gz: lmtpd-0.9.19/set.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

static char const rcsid[] =
"$Id: set.c,v 1.1 2003/03/14 16:30:32 lwa Exp $";

#include "config.h"
#include <ctype.h>
#include <inttypes.h>

/* support of non ascii systems */

uint32_t get_set(char a) {
  switch(a) {
  case 'a': case 'A': return 1 << 0;
  case 'b': case 'B': return 1 << 1;
  case 'c': case 'C': return 1 << 2;
  case 'd': case 'D': return 1 << 3;
  case 'e': case 'E': return 1 << 4;
  case 'f': case 'F': return 1 << 5;
  case 'g': case 'G': return 1 << 6;
  case 'h': case 'H': return 1 << 7;
  case 'i': case 'I': return 1 << 8;
  case 'j': case 'J': return 1 << 9;
  case 'k': case 'K': return 1 << 10;
  case 'l': case 'L': return 1 << 11;
  case 'm': case 'M': return 1 << 12;
  case 'n': case 'N': return 1 << 13;
  case 'o': case 'O': return 1 << 14;
  case 'p': case 'P': return 1 << 15;
  case 'q': case 'Q': return 1 << 16;
  case 'r': case 'R': return 1 << 17;
  case 's': case 'S': return 1 << 18;
  case 't': case 'T': return 1 << 19;
  case 'u': case 'U': return 1 << 20;
  case 'v': case 'V': return 1 << 21;
  case 'w': case 'W': return 1 << 22;
  case 'x': case 'X': return 1 << 23;
  case 'y': case 'Y': return 1 << 24;
  case 'z': case 'Z': return 1 << 25;
  default: return 0;
  }
}

==> lmtpd-0.10.7.tar.gz: lmtpd-0.10.7/set.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "config.h"

static char const rcsid[] UNUSED =
"$Id: set.c,v 1.2 2004/10/26 09:59:20 lwa Exp $";


#include <ctype.h>
#include <inttypes.h>

/* support of non ascii systems */

uint32_t get_set(char a) {
  switch(a) {
  case 'a': case 'A': return 1 << 0;
  case 'b': case 'B': return 1 << 1;
  case 'c': case 'C': return 1 << 2;
  case 'd': case 'D': return 1 << 3;
  case 'e': case 'E': return 1 << 4;
  case 'f': case 'F': return 1 << 5;
  case 'g': case 'G': return 1 << 6;
  case 'h': case 'H': return 1 << 7;
  case 'i': case 'I': return 1 << 8;
  case 'j': case 'J': return 1 << 9;
  case 'k': case 'K': return 1 << 10;
  case 'l': case 'L': return 1 << 11;
  case 'm': case 'M': return 1 << 12;
  case 'n': case 'N': return 1 << 13;
  case 'o': case 'O': return 1 << 14;
  case 'p': case 'P': return 1 << 15;
  case 'q': case 'Q': return 1 << 16;
  case 'r': case 'R': return 1 << 17;
  case 's': case 'S': return 1 << 18;
  case 't': case 'T': return 1 << 19;
  case 'u': case 'U': return 1 << 20;
  case 'v': case 'V': return 1 << 21;
  case 'w': case 'W': return 1 << 22;
  case 'x': case 'X': return 1 << 23;
  case 'y': case 'Y': return 1 << 24;
  case 'z': case 'Z': return 1 << 25;
  default: return 0;
  }
}
